betty.ancestry.person module - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# betty.ancestry.person module

Data types describing persons.

final class betty.ancestry.person.Person

  Bases: `ShorthandPluginBase`, `HasFileReferences`, `HasCitations`, `HasNotes`, `HasLinks`, `HasPrivacy`, `UserFacingEntity`, `Entity`

  A person.

  __init__(*, id: str | None = None, file_references: Iterable[FileReference] | ToManyResolver[FileReference] | None = None, citations: Iterable['Citation'] | ToManyResolver['Citation'] | None = None, links: MutableSequence[Link] | None = None, notes: Iterable[Note] | ToManyResolver[Note] | None = None, privacy: Privacy | None = None, public: bool | None = None, private: bool | None = None, parents: Iterable[Person] | ToManyResolver[Person] | None = None, children: Iterable[Person] | ToManyResolver[Person] | None = None, presences: Iterable['Presence'] | ToManyResolver['Presence'] | None = None, names: Iterable['PersonName'] | ToManyResolver['PersonName'] | None = None, gender: Gender | None = None)
  property ancestors: Iterator[Person]

    All ancestors.

  children

    A bidirectional *-to-many entity type association.

  property descendants: Iterator[Person]

    All descendants.

  async dump_linked_data(project: Project) → DumpMapping[Dump]

    Dump this instance to JSON-LD.

  property label: Localizable

    The entity’s human-readable label.

  async classmethod linked_data_schema(project: Project) → JsonLdObject

    Define the JSON Schema for `betty.json.linked_data.LinkedDataDumpable.dump_linked_data()`.

  names

    A bidirectional *-to-many entity type association.

  parents

    A bidirectional *-to-many entity type association.

  classmethod plugin_label_plural() → Localizable

    The human-readable entity type label, plural.

  presences

    A bidirectional *-to-many entity type association.

  property siblings: Iterator[Person]

    All siblings.